@@ -9,7 +9,9 @@ case "$1" in
         #
         # Remove socket directory in Postfix chroot environment
         #
-        rmdir --ignore-fail-on-non-empty $MILTER_SOCKDIR
+        set +e
+        [ -d "$MILTER_SOCKDIR" ] && rmdir --ignore-fail-on-non-empty "$MILTER_SOCKDIR"
+        set -e
     ;;
     purge)
         # ignore errors during purge
